@@ -1,3 +1,11 @@
+###############################################################################
+# Field Names
+###############################################################################
+
+
+COLLECTION = 'Collection'
+
+
 ###############################################################################
 # Field Types
 ###############################################################################
@@ -35,6 +43,9 @@ MULTIPLE_OPTION = 'MULTIPLE_OPTION'
 ONE_TO_ONE = 'ONE_TO_ONE'
 
 
+ONE_TO_MANY = 'ONE_TO_MANY'
+
+
 MANY_TO_ONE = 'MANY_TO_ONE'
 
 
